# T3CO Modules

The T3CO submodules are categorized into:

- Sweep module:
  - [sweep.py](sweep.md)
- Run Modules:
  - [run_scenario.py](run_scenario.md)
  - [generateinputs.py](generateinputs.md)
  - [Global.py](global.md)
- TCO Modules:
  - [opportunity_costs.py](opportunity_cost.md)
  - [tcocalc.py](tcocalc.md)
  - [tco_analysis.py](tco_analysis.md)
  - [tco_stock_emissions.py](tco_stock_emissions.md)
- MOO Modules:
  - [moo.py](moo.md)
- Objectives Modules:
  - [accel.py](accel.md)
  - [gradeability.py](gradeability.md)
  - [fueleconomy.py](fueleconomy.md)
